@@ -1,3 +1,3 @@
-from .app import App
+from .cakework import Cakework
 from .client import Client
 from .exceptions import CakeworkError
\ No newline at end of file
