@@ -25,6 +25,8 @@ import time
 import threading
 import requests
 import logging
+import http.client
+from cakework import auth
 
 logging.basicConfig(level=logging.INFO)
 
@@ -39,18 +41,21 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
 
     def RunActivity(self, request, context):
         # update to in progress
-        response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"})
+        scope = "update:status update:result"
+        token = auth.get_token("l2OCkl1RIrWgYwaHeH394C0bXKJRIucI", "aYUDERY08rNhciuebW5rpShcU_KmcyY-RK-A55-ltkSmt-1mvAfAcJdVTsZDEBRh", scope) # TODO remove this from open source code
+        headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
+        response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": request.userId, "app": request.app, "requestId": request.requestId, "status": "IN_PROGRESS"}, headers=headers)
         # TODO check the response
         parameters = json.loads(request.parameters)
         # parameters = json.loads(request.parameters) # instead of passing a dict (parameters), pass a variable number of parameters 
-        task = threading.Thread(target=self.background, args=[request.userId, request.app, request.requestId, parameters])
+        task = threading.Thread(target=self.background, args=[request.userId, request.app, request.requestId, parameters, token])
         task.daemon = True # Q: does returning kill the task?
         task.start()
         # what should we return? now, the client is no longer hitting the grpc server
         return cakework_pb2.Reply(result=json.dumps("worker started task")) # TODO this should return the request id
 
     # note: we need to get the request id in here as well
-    def background(self, user_id, app, request_id, parameters):
+    def background(self, user_id, app, request_id, parameters, token):
         res = ""
         # logging.info("starting background task with parameters: " + str(parameters))
         try:
@@ -59,9 +64,10 @@ class Cakework(cakework_pb2_grpc.CakeworkServicer):
             # TODO call the frontend api to update the status and result
             
             logging.info("Finished request " + request_id)
-            response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)})
+            headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
+            response = requests.patch(f"{self.frontend_url}/update-result", json={"userId": user_id, "app": app, "requestId": request_id, "result": json.dumps(res)}, headers=headers)
             # TODO check the response
-            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"})
+            response = requests.patch(f"{self.frontend_url}/update-status", json={"userId": user_id, "app": app, "requestId": request_id, "status": "SUCCEEDED"}, headers=headers)
 
         except Exception as e:
             logging.exception("Error occurred while running task", exc_info=True)
