@@ -11,6 +11,7 @@ import logging
 from cakework import exceptions
 from urllib3.exceptions import NewConnectionError
 import os
+from cakework import auth
 
 # TODO: need to re-enable TLS for the handlers in the fly.toml file. Try these settings: https://community.fly.io/t/urgent-grpc-server-unreachable-via-grpcurl/2694/12 for alpn
 # TODO figure out how to configure the settings for fly.toml for grpc!
@@ -30,11 +31,18 @@ class Client:
             self.frontend_url = "https://cakework-frontend.fly.dev"
 
         response = None
+        self.headers = None
         try:
-            # Q: status 200 vs 201??? what's the diff?
-            # response = requests.get(f"{self.frontend_url}/get-user", json={"userId": "105349741723321386951"}) 
 
-            response = requests.get(f"{self.frontend_url}/get-user-from-client-token", json={"token": client_token})      # Q: should this take app?        
+            # based on the particular user id, how do we fetch user credentials and get a token on behalf of the user?
+            # need SOME sort of token first
+            token = auth.get_token("LtM7DMVVmENYKIL8UYIvcUqmQxxwru5B", "CJ2HtEMSGMWVyxxlHfuluPLQ4-ZDrcOTIF_DDUmabkog24DuHLV8ElaL08gk8wVG", "get:user_from_client_token get:status get:result submit:task")
+            self.headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
+            response = requests.get(f"{self.frontend_url}/get-user-from-client-token", json={"token": client_token}, headers=self.headers)      # Q: should this take app?        
+               
+            # if dont' get a avalid user
+            # TODO raise exception
+                       
             # TODO: handle error for if can't get a user from the client token. technically
             # we should be getting a JWT token instead first
             response.raise_for_status() # TODO delete this?
@@ -59,20 +67,20 @@ class Client:
             if response.status_code == 200:
                 response_json = response.json()
                 self.user_id = response_json["id"] # Q: how to return None if process is still executing? instead of empty string
+                self.headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + token}
             else:
                 raise exceptions.CakeworkError("Error happened while trying to get the user from the client token")
         else:
             raise exceptions.CakeworkError("Error happened while trying to get the user from the client token")
 
         self.local = local
-
- 
+        
     def get_status(self, request_id):
         response = None
         try:
             # Q: status 200 vs 201??? what's the diff?
             # TODO strip app from everywhere
-            response = requests.get(f"{self.frontend_url}/get-status", json={"userId": self.user_id, "app": self.project, "requestId": request_id})                
+            response = requests.get(f"{self.frontend_url}/get-status", json={"userId": self.user_id, "app": self.project, "requestId": request_id}, headers=self.headers)                
             response.raise_for_status() # TODO delete this?
             # TODO: handle http error, or request id not found error
         except requests.exceptions.HTTPError as errh:
@@ -108,7 +116,7 @@ class Client:
         response = None
         try:
             # Q: status 200 vs 201??? what's the diff?
-            response = requests.get(f"{self.frontend_url}/get-result", json={"userId": self.user_id, "app": self.project, "requestId": request_id})                
+            response = requests.get(f"{self.frontend_url}/get-result", json={"userId": self.user_id, "app": self.project, "requestId": request_id}, headers=self.headers)                
             response.raise_for_status() # TODO delete this?
             # TODO: handle http error, or request id not found error
         except requests.exceptions.HTTPError as errh:
@@ -143,7 +151,7 @@ class Client:
         def method(*args):
             sanitized_name = name.lower()
             sanitized_name = name.replace('_', '-')          
-            response = requests.post(f"{self.frontend_url}/submit-task", json={"userId": self.user_id, "app": self.project, "task": sanitized_name, "parameters": json.dumps(args)})
+            response = requests.post(f"{self.frontend_url}/submit-task", json={"userId": self.user_id, "app": self.project, "task": sanitized_name, "parameters": json.dumps(args)}, headers=self.headers)
             response_json = response.json()
             request_id = response_json["requestId"] # this may be null?
             return request_id
@@ -151,4 +159,4 @@ class Client:
         return method
     
 # if __name__ == '__main__':
-#     run()
\ No newline at end of file
+#     run() 
\ No newline at end of file
